@@ -90,13 +90,13 @@ class LazySettings(LazyObject):
         e.g: ROOT_PATH='/' is transformed into `ROOT_PATH_FOR_DYNACONF`
         """
 
-        mispells = {
+        misspells = {
             "settings_files": "settings_file",
             "SETTINGS_FILES": "SETTINGS_FILE",
             "environment": "environments",
             "ENVIRONMENT": "ENVIRONMENTS",
         }
-        for misspell, correct in mispells.items():
+        for misspell, correct in misspells.items():
             if misspell in kwargs:
                 kwargs[correct] = kwargs.pop(misspell)
 
@@ -229,7 +229,7 @@ class Settings:
         self._loaded_py_modules = []
         self._loaded_files = []
         self._deleted = set()
-        self._store = DynaBox(box_settings=self)
+        self._store = kwargs.pop("_store", DynaBox(box_settings=self))
         self._env_cache = {}
         self._loaded_by_loaders: dict[SourceMetadata | str, Any] = {}
         self._loaders = []
@@ -432,6 +432,12 @@ class Settings:
         :param default: In case of not found it will be returned
         :param parent: Is there a pre-loaded parent in a nested data?
         """
+        # if parent is not traverseable raise error
+        if parent and not hasattr(parent, "get"):
+            raise AttributeError(
+                f"cannot lookup {dotted_key!r} from {type(parent).__name__!r}"
+            )
+
         split_key = dotted_key.split(".")
         name, keys = split_key[0], split_key[1:]
         result = self.get(name, default=default, parent=parent, **kwargs)
@@ -918,7 +924,7 @@ class Settings:
         :param key: The key to store. Can be of any type.
         :param value: The raw value to parse and store
         :param loader_identifier: Optional loader name e.g: toml, yaml etc.
-                                  Or isntance of SourceMetadata
+                                  Or instance of SourceMetadata
         :param tomlfy: Bool define if value is parsed by toml (defaults False)
         :param merge: Bool define if existing nested data will be merged.
         :param validate: Bool define if validation will be triggered
@@ -962,6 +968,15 @@ class Settings:
             self.store.get(key, None) if not isinstance(parsed, Lazy) else None
         )
 
+        if getattr(parsed, "_dynaconf_insert", False):
+            # `@insert` calls insert in a list by index
+            if existing and isinstance(existing, list):
+                source_metadata = source_metadata._replace(merged=True)
+                existing.insert(parsed.index, parsed.unwrap())
+                parsed = existing
+            else:
+                parsed = [parsed.unwrap()]
+
         if getattr(parsed, "_dynaconf_del", None):
             self.unset(key, force=True)  # `@del` in a first level var.
             return
@@ -1179,14 +1194,11 @@ class Settings:
             core_loader.load(self, env, silent=silent, key=key)
 
         self.load_includes(env, silent=silent, key=key)
-        self._store._box_config["_bypass_evaluation"] = True
 
         # execute hooks
         execute_module_hooks("post", self, env, silent=silent, key=key)
         execute_instance_hooks(self, "post", self._post_hooks)
 
-        self._store._box_config.pop("_bypass_evaluation", None)
-
     def pre_load(self, env, silent, key):
         """Do we have any file to pre-load before main settings file?"""
         preloads = self.get("PRELOAD_FOR_DYNACONF", [])
@@ -1224,15 +1236,27 @@ class Settings:
             validate = self.get("VALIDATE_ON_UPDATE_FOR_DYNACONF")
 
         env = (env or self.current_env).upper()
+
         files = ensure_a_list(path)
         if files:
+            # Using inspect take the filename and line number of the caller
+            # to be used in the source_metadata
+            frame = inspect.currentframe()
+            caller = inspect.getouterframes(frame)[1]
             already_loaded = set()
             for _filename in files:
-
                 # load_file() will handle validation later
                 with suppress(ValidationError):
+                    source_metadata = SourceMetadata(
+                        loader=f"load_file@{caller.filename}:{caller.lineno}",
+                        identifier=_filename,
+                        env=env,
+                    )
                     if py_loader.try_to_load_from_py_module_name(
-                        obj=self, name=_filename, silent=True
+                        obj=self,
+                        name=_filename,
+                        silent=True,
+                        identifier=source_metadata,
                     ):
                         # if it was possible to load from module name
                         # continue the loop.
@@ -1250,14 +1274,10 @@ class Settings:
                     filepath = os.path.join(root_dir, str(_filename))
 
                 paths = [
-                    p
-                    for p in sorted(glob(filepath, root_dir=self._root_path))
-                    if ".local." not in p
+                    p for p in sorted(glob(filepath)) if ".local." not in p
                 ]
                 local_paths = [
-                    p
-                    for p in sorted(glob(filepath, root_dir=self._root_path))
-                    if ".local." in p
+                    p for p in sorted(glob(filepath)) if ".local." in p
                 ]
 
                 # Handle possible *.globs sorted alphanumeric
@@ -1267,6 +1287,11 @@ class Settings:
 
                     # load_file() will handle validation later
                     with suppress(ValidationError):
+                        source_metadata = SourceMetadata(
+                            loader=f"load_file@{caller.filename}:{caller.lineno}",
+                            identifier=path,
+                            env=env,
+                        )
                         settings_loader(
                             obj=self,
                             env=env,
@@ -1274,6 +1299,7 @@ class Settings:
                             key=key,
                             filename=path,
                             validate=validate,
+                            identifier=source_metadata,
                         )
                         already_loaded.add(path)
 
@@ -1359,7 +1385,7 @@ class Settings:
             value = self.get_fresh(key)
             return value is True or value in true_values
 
-    def populate_obj(self, obj, keys=None, ignore=None):
+    def populate_obj(self, obj, keys=None, ignore=None, internal=False):
         """Given the `obj` populate it using self.store items.
 
         :param obj: An object to be populated, a class instance.
@@ -1368,6 +1394,9 @@ class Settings:
         """
         keys = keys or self.keys()
         for key in keys:
+            if not internal:
+                if key in UPPER_DEFAULT_SETTINGS:
+                    continue
             key = upperfy(key)
             if ignore and key in ignore:
                 continue
